pub struct InternalServerError<T>(pub T);Available on crate feature
error-response only.Expand description
Convenience response to create an error response from a non-IntoResponse error
This provides a method to quickly respond with an error that does not implement
the IntoResponse trait itself. Error details are logged using tracing::error!
and a generic 500 Internal Server Error response is returned to the client without
exposing error details.
use axum_extra::response::InternalServerError;
use axum_core::response::IntoResponse;
async fn maybe_error() -> Result<String, InternalServerError<Error>> {
try_thing().map_err(InternalServerError)?;
// do something on success
}Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Debug> Debug for InternalServerError<T>
impl<T: Debug> Debug for InternalServerError<T>
Sourceimpl<T: Error + 'static> IntoResponse for InternalServerError<T>
impl<T: Error + 'static> IntoResponse for InternalServerError<T>
Sourcefn into_response(self) -> Response
fn into_response(self) -> Response
Create a response.